==> ocre_v0_034.tgz: ocre-0.034/ocre/src/glifos.h <==

#include "base.h"
#include "imag.h"
#include "lista.h"

#ifndef _GLIFOS_H
#define _GLIFOS_H

enum {glifCar, glifBlan, glifClin, glifEspv, glifNul, glifArtf, glifSecuen,
      glifCompSec, glifCompPal, glifCompLin, glifCompClmp,
      glifCompPagina, glifCompPliego, glifCompTabla, glifZz};
    /* si se cambia, revisar glifoCompuesto() en glifo.c */
    //               y describeGlifo
    //               y cuentaTiposenGlifo, imprimeRecuentoTiposenGlifo

enum {reconNulo, reconComp, reconDcswft, reconPreg, reconMisc, reconDicc,
      reconZz};
enum {clmpParfEstNulo, clmpParfEstOrdinario, clmpParfEstModerno};

typedef struct teglifo{
  int tipo;
  char * letras;
  struct tevent * venDeGlifo;
  struct tevent * ven2DeGlifo;  // para mineria de letras
  struct teglifo * glifBase;
  struct telistadglifo * listaGlifos;
  int base, alturax;
  int lizq, lder;
  int recon;
  int recindc;                 // reconocimiento, arbolesb, contador
  int recparecc;               // reconocimiento, por parecido, contador
  int clmpInclizq, clmpInclder, clmpAlinizq, clmpAlinder, clmpParfEst;
  int linLimizq, linLimder, linBaseEncol, linAlinizq, linAlinder;
  lista tbllista;
  struct teglifo * parteLogAnt, * parteLogSig;
  int ideglifo;
  } * tglifo;

typedef struct tenodolglifo{
  struct tenodolglifo *anterior, *siguiente;
  struct teglifo *aglifo;
  } * tnodolglifo;

typedef struct telistadglifo{
  tnodolglifo primero, ultimo;
  } * tlistadglifo;

#define GLIfoDeVen(v) ((tglifo)(v->abstract))
#define GLifoDeVen abstract

#endif

Boolean glifoCompuesto (tglifo glifo);

tglifo duplicaGlifo (tglifo glifo);

tglifo glifoClinNuevo ();

tglifo glifoBlanNuevo ();

tglifo glifoEspvNuevo ();

tglifo glifoLetNuevo (char *let);

void ponLetGlifo (tglifo glifo, char *let);

tglifo glifoCompSecNuevo ();

tglifo glifoCompPalNuevo ();

tglifo glifoCompLinNuevo ();

tglifo glifoCompClmpNuevo ();

tglifo glifoCompPaginaNuevo ();

tglifo glifoCompPliegoNuevo ();

tglifo glifoCompTablaNuevo ();

tglifo glifoDeArrayDeGlifos (tglifo *glifos, int n);

Boolean listadglifoVacia (tlistadglifo ldglifo);

tnodolglifo nodolglifoDeGlifo (tglifo glifo);

tglifo glifoBasenTipo (tglifo glifo, int tipoGlifo);

void casaGlifoVent (tglifo glifo, tvent vent);

int separacionHorizEntreGlifos (tglifo glifo1, tglifo glifo2);

void adoptaGlifo (tglifo glifop, tglifo glifoh);

void ponpadreGlifo (tglifo glifop, tglifo glifoh);

Boolean enlazaLogGlifos (tglifo glif1, tglifo glif2);

void describeGlifo (tglifo glifo, int niv);

void aplicaGtRFncD (tglifo glifo, int tipo, void fn(tglifo, tpgen), tpgen datos);

void aplicaGtRFn (tglifo glifo, int tipo, void fn(tglifo));

void cuentaTiposenGlifo (int **ncntglifo, tglifo glifo);

void cuentaTiposReconocimientos (int **ncnrecon, tglifo glifo);

void cuentaTiposReconocimientosDcsw (int **ncnreconDcsw, tglifo glifo);

void imprimeTasaReconocimientosDcsw (int *cnreconDcsw, int *cntglifo);

void imprimeRecuentoReconocimientosDcsw (int *cnreconDcsw);

void cuentaTiposReconocimientosComp (int **ncnreconComp, tglifo glifo);

void imprimeTasaReconocimientosComp (int *cnreconComp, int *cntglifo);

void imprimeRecuentoReconocimientosComp (int *cnreconComp);

void imprimeRecuentoReconocimientos (int *cnrecon);

void imprimeRecuentoTiposenGlifo (int *cntglifo);

tlistadglifo listadglifoNueva ();

void aniadeGlifoacomlista (tlistadglifo ldglifo, tglifo glifo);

void aniadeGlifoafinlista (tlistadglifo ldglifo, tglifo glifo);

void aniadeGlifoalistaAntes (tlistadglifo ldglifo, tglifo glifo, tnodolglifo nodolGlifo);

void eliminaNGlifodelista (tlistadglifo ldglifo, tnodolglifo nodolGlifo);

int longListagl (tlistadglifo ldglifo);

void substituye2glifospor1 (tnodolglifo nodolGlifo, tglifo glifoNuevo);

tglifo glifoUnionConSiguiente (tnodolglifo nodolGlifo);

void escribePalabradeGlifo (tpgen glifo);

void escribePalabradeGlifoL (tpgen glifo);

void escribePalabradeGlifoyPares (tpgen glifo);

void escribePalabrasdeGlifosenLista (tlistadglifo ldglifo);

void escribePalabrasLogdeGlifosenLista (tlistadglifo ldglifo);

void escribeLetrasdeGlifosenLista (tlistadglifo ldglifo, int * nc);

void escribeEnFnomLetrasdeGlifosenLista (char *nf, tlistadglifo ldglifo);

void baseyalturaxDeGlifo (int *base, int *alturax, tglifo glifo);

void alineamientoNormalizado (int *dyNorm, int *dy2Norm, int *tyNorm, tglifo glifo);

void escribeVentanasdeGlifosenLista (tglifo glifo, int *nc, char *ndir);

void numeraGlifosenLista (tglifo glifo, int *nc);

void marcaGlifosNoReconocidos (tglifo glifoColumnaP) ;

void listadePalabrasEnGlifo (lista *nlista, tglifo glifo);

void listadePalabrasLenGlifo (lista *nlista, tglifo glifo);

Boolean glifoAcabaenchar (tglifo glifoc, char ch);

int nincognitasEnGlifo (tglifo glifo);

int nincognitasEnLGlifo (tglifo glifo);

lista listaIncognitasEnGlifo (tglifo glifo);

lista listaIncognitasEnGlifoL (tglifo glifo);

lista partesDePalabraNenGlifo (tglifo glifo);

lista partesDePalabraLenGlifo (tglifo glifo);

lista listaGlifosConLetraEnGlifo (tglifo glifo, char *letra);

void cambiaNEnGlifo (tglifo glifoPal, char cant, char cdesp);

void cambiaStrNEnGlifo (tglifo glifo, char *sant, char *sdesp);

void enlazaPalabrasPartidas (tglifo glifoColumnaP);

void enlazaPalabraPartida (tglifo glifoPalabra);

==> ocre_v0_037.tgz: ocre-0.037/ocre/src/glifos.h <==

#include "base.h"
#include "imag.h"
#include "lista.h"

#ifndef _GLIFOS_H
#define _GLIFOS_H

// cambio enumeracion -> cambiar  'nombreTipoGlifo' en glifos.c
enum {glifCar, glifBlan, glifClin, glifEspv, glifNul, glifArtf, glifSecuen,
      glifCompSec, glifCompPal, glifCompLin, glifCompClmp,
      glifCompPagina, glifCompPliego, glifCompTabla, glifZz};
    /* si se cambia, revisar glifoCompuesto() en glifo.c */
    //               y describeGlifo
    //               y cuentaTiposenGlifo, imprimeRecuentoTiposenGlifo

// cambio enumeracion -> cambiar  'nombreTipoReconocimiento' en glifos.c
enum {reconNulo,
      reconComp, reconDcswft, reconDcswftw,
      reconPreg, reconMisc, reconDicc,
      reconZz};

enum {clmpParfEstNulo, clmpParfEstOrdinario, clmpParfEstModerno};

typedef struct teglifo{
  int tipo;
  char * letras;
  char * propw;
  struct tevent * venDeGlifo;
  struct tevent * ven2DeGlifo;  // para mineria de letras
  struct teglifo * glifBase;
  struct telistadglifo * listaGlifos;
  int base, alturax;
  int lizq, lder;
  int recon;
  int recindc;                 // reconocimiento, arbolesb, contador
  int recparecc;               // reconocimiento, por parecido, contador
  int clmpInclizq, clmpInclder, clmpAlinizq, clmpAlinder, clmpParfEst;
  int linLimizq, linLimder, linBaseEncol, linAlinizq, linAlinder;
  lista tbllista;
  struct teglifo * parteLogAnt, * parteLogSig;
  int ideglifo;
  } * tglifo;

typedef struct tenodolglifo{
  struct tenodolglifo *anterior, *siguiente;
  struct teglifo *aglifo;
  } * tnodolglifo;

typedef struct telistadglifo{
  tnodolglifo primero, ultimo;
  } * tlistadglifo;

#define GLIfoDeVen(v) ((tglifo)(v->abstract))
#define GLifoDeVen abstract

#endif

Boolean glifoCompuesto (tglifo glifo);

tglifo duplicaGlifo (tglifo glifo);

tglifo glifoClinNuevo ();

tglifo glifoBlanNuevo ();

tglifo glifoEspvNuevo ();

tglifo glifoLetNuevo (char *let);

void ponLetGlifo (tglifo glifo, char *let);

void ponLetwGlifo (tglifo glifo, char *letw);

tglifo glifoCompSecNuevo ();

tglifo glifoCompPalNuevo ();

tglifo glifoCompLinNuevo ();

tglifo glifoCompClmpNuevo ();

tglifo glifoCompPaginaNuevo ();

tglifo glifoCompPliegoNuevo ();

tglifo glifoCompTablaNuevo ();

tglifo glifoDeArrayDeGlifos (tglifo *glifos, int n);

Boolean listadglifoVacia (tlistadglifo ldglifo);

tnodolglifo nodolglifoDeGlifo (tglifo glifo);

tglifo glifoBasenTipo (tglifo glifo, int tipoGlifo);

void casaGlifoVent (tglifo glifo, tvent vent);

int separacionHorizEntreGlifos (tglifo glifo1, tglifo glifo2);

void adoptaGlifo (tglifo glifop, tglifo glifoh);

void ponpadreGlifo (tglifo glifop, tglifo glifoh);

Boolean enlazaLogGlifos (tglifo glif1, tglifo glif2);

tglifo seleccionaSubglifo (tglifo glifo, char *selec);

void describeGlifo (tglifo glifo, int niv);

void aplicaGtRFncD (tglifo glifo, int tipo, void fn(tglifo, tpgen), tpgen datos);

void aplicaGtRFn (tglifo glifo, int tipo, void fn(tglifo));

void cuentaTiposenGlifo (int **ncntglifo, tglifo glifo);

void cuentaTiposReconocimientos (int **ncnrecon, tglifo glifo);

void cuentaTiposReconocimientosDcsw (int **ncnreconDcsw, tglifo glifo);

void imprimeTasaReconocimientosDcsw (int *cnreconDcsw, int *cntglifo);

void imprimeRecuentoReconocimientosDcsw (int *cnreconDcsw);

void cuentaTiposReconocimientosComp (int **ncnreconComp, tglifo glifo);

void imprimeTasaReconocimientosComp (int *cnreconComp, int *cntglifo);

void imprimeRecuentoReconocimientosComp (int *cnreconComp);

void imprimeRecuentoReconocimientos (int *cnrecon);

void imprimeRecuentoTiposenGlifo (int *cntglifo);

tlistadglifo listadglifoNueva ();

void aniadeGlifoacomlista (tlistadglifo ldglifo, tglifo glifo);

void aniadeGlifoafinlista (tlistadglifo ldglifo, tglifo glifo);

void aniadeGlifoalistaAntes (tlistadglifo ldglifo, tglifo glifo, tnodolglifo nodolGlifo);

void eliminaNGlifodelista (tlistadglifo ldglifo, tnodolglifo nodolGlifo);

int longListagl (tlistadglifo ldglifo);

void substituye2glifospor1 (tnodolglifo nodolGlifo, tglifo glifoNuevo);

tglifo glifoUnionConSiguiente (tnodolglifo nodolGlifo);

void escribePalabradeGlifo (tpgen glifo);

void escribePalabradeGlifoL (tpgen glifo);

void escribePalabradeGlifoyPares (tpgen glifo);

void escribePalabrasdeGlifosenLista (tlistadglifo ldglifo);

void escribePalabrasLogdeGlifosenLista (tlistadglifo ldglifo);

void escribeLetrasdeGlifosenLista (tlistadglifo ldglifo, int * nc);

void escribeEnFnomLetrasdeGlifosenLista (char *nf, tlistadglifo ldglifo);

void baseyalturaxDeGlifo (int *base, int *alturax, tglifo glifo);

void alineamientoNormalizado (int *dyNorm, int *dy2Norm, int *tyNorm, tglifo glifo);

void escribeVentanasdeGlifosenLista (tglifo glifo, int *nc, char *ndir);

void numeraGlifosenLista (tglifo glifo, int *nc);

void marcaGlifosNoReconocidos (tglifo glifoColumnaP) ;

void listadePalabrasEnGlifo (lista *nlista, tglifo glifo);

void listadePalabrasLenGlifo (lista *nlista, tglifo glifo);

Boolean glifoAcabaenchar (tglifo glifoc, char ch);

int nincognitasEnGlifo (tglifo glifo);

int nincognitasEnLGlifo (tglifo glifo);

lista listaIncognitasEnGlifo (tglifo glifo);

lista listaIncognitasEnGlifoL (tglifo glifo);

lista partesDePalabraNenGlifo (tglifo glifo);

lista partesDePalabraLenGlifo (tglifo glifo);

lista listaGlifosConLetraEnGlifo (tglifo glifo, char *letra);

void cambiaNEnGlifo (tglifo glifoPal, char cant, char cdesp);

void cambiaStrNEnGlifo (tglifo glifo, char *sant, char *sdesp);

void  corrigeGuionesFindeLinea (tglifo glifoColumnaP);

void enlazaPalabrasPartidas (tglifo glifoColumnaP);

void enlazaPalabraPartida (tglifo glifoPalabra);

void ponCapitularenGlifoCP (tglifo glifoColumnaP, tvent ventCap, tvent vent);
